==> freeplane_1.5.16.orig.tar.gz: freeplane-1.5.16/freeplane/src/main/java/org/freeplane/features/map/ToggleFoldedAction.java <==
/*
 *  Freeplane - mind map editor
 *  Copyright (C) 2008 Joerg Mueller, Daniel Polansky, Christian Foltin, Dimitry Polivaev
 *
 *  This file is modified by Dimitry Polivaev in 2008.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.freeplane.features.map;

import java.awt.event.ActionEvent;
import java.util.Collection;

import org.freeplane.core.ui.AFreeplaneAction;
import org.freeplane.features.mode.Controller;

/**
 * @author foltin
 */
class ToggleFoldedAction extends AFreeplaneAction {
	static final String NAME = "toggleFolded";
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	public ToggleFoldedAction() {
		super("ToggleFoldedAction");
	}

	public void actionPerformed(final ActionEvent e) {
		MapController r = Controller.getCurrentModeController().getMapController();
		final Collection<NodeModel> selectedNodes = r.getSelectedNodes();
		if(selectedNodes.size() > 1)
			r.toggleFolded(selectedNodes);
		else {
			final NodeModel selectedNode = r.getSelectedNode();
			r.setFoldedAndScroll(selectedNode, ! selectedNode.isFolded());
		}
	}
}

==> freeplane_1.5.18.orig.tar.gz: freeplane-1.5.18/freeplane/src/main/java/org/freeplane/features/map/ToggleFoldedAction.java <==
/*
 *  Freeplane - mind map editor
 *  Copyright (C) 2008 Joerg Mueller, Daniel Polansky, Christian Foltin, Dimitry Polivaev
 *
 *  This file is modified by Dimitry Polivaev in 2008.
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.freeplane.features.map;

import java.awt.event.ActionEvent;
import java.util.Collection;

import org.freeplane.core.ui.AFreeplaneAction;
import org.freeplane.features.mode.Controller;

/**
 * @author foltin
 */
class ToggleFoldedAction extends AFreeplaneAction {
	static final String NAME = "toggleFolded";
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	public ToggleFoldedAction() {
		super("ToggleFoldedAction");
	}

	public void actionPerformed(final ActionEvent e) {
		MapController r = Controller.getCurrentModeController().getMapController();
		final Collection<NodeModel> selectedNodes = r.getSelectedNodes();
		if(selectedNodes.size() > 1)
			r.toggleFolded(selectedNodes);
		else {
			final NodeModel selectedNode = r.getSelectedNode();
			boolean folded = Controller.getCurrentController().getMapViewManager().isFoldedOnCurrentView(selectedNode);
			r.setFoldedAndScroll(selectedNode, ! folded);
		}
	}
}
